# eido

[![Build Status](https://travis-ci.org/pepkit/eido.svg?branch=master)](https://travis-ci.org/pepkit/eido)
[![Coverage Status](https://coveralls.io/repos/github/pepkit/eido/badge.svg?branch=master)](https://coveralls.io/github/pepkit/eido?branch=master)
[![PEP compatible](http://pepkit.github.io/img/PEP-compatible-green.svg)](http://pepkit.github.io)

[PEP](http://pepkit.github.io) validation tool based on [`jsonschema`](https://github.com/Julian/jsonschema) package.

See [this jupyter notebook](docs_jupyter/demo.ipynb) for usage demonstration

---
*Eidos* is a Greek term meaning "form" "essence", "type" or "species". See Plato's theory of Forms and Aristotle's theory of universals
